translate.storage.odf_io

Package translate :: Package storage :: Module odf_io |
[hide private]
[frames] | no frames]

# Module odf_io

source code

Functions | [hide private]
open_odf(filename) | source code
copy_odf(input_zip, output_zip, exclusion_list) | source code
namespaced(nsmap, short_namespace, tag) | source code
add_file(output_zip, manifest_data, new_filename, new_data) | source code

Variables | [hide private]
| __package__ = ``'``translate.storage``'``

Imports: zipfile, etree, XmlNamer